<?php
	
/*
Plugin Name: Booked Front-end Agents
Plugin URI: http://booked.boxydemos.com
Description: Adds the ability for Booking Agents to manage their appointments on the front-end.
Version: 1.1.5
Author: Boxy Studio
Author URI: https://www.boxystudio.com
*/

define('BOOKEDFEA_PLUGIN_DIR', dirname(__FILE__));
define('BOOKEDFEA_PLUGIN_URL', WP_PLUGIN_URL . '/booked-frontend-agents');
define('BOOKEDFEA_VERSION','1.1.5');

// Include the required class for plugin updates.
require_once('updates/plugin-update-checker.php');
$BookedFEA_BoxyUpdateChecker = PucFactory::buildUpdateChecker('http://boxyupdates.com/get/?action=get_metadata&slug=booked-frontend-agents', __FILE__, 'booked-frontend-agents');

// Is Booked installed and active?
if( in_array('booked/booked.php',apply_filters('active_plugins',get_option('active_plugins')))) {
	
	if(!class_exists('bookedfea_plugin')) {
		class bookedfea_plugin {
			
			public function __construct() {
				
				add_action('init', array(&$this, 'booked_fea_init') );
				add_action('wp_enqueue_scripts', array(&$this, 'front_end_scripts'));
				add_action('wp_enqueue_scripts', array(&$this, 'front_end_styles'));
				add_action('wp_head', array(&$this, 'inline_scripts'),9);
				
				require_once(sprintf("%s/includes/shortcodes.php", BOOKEDFEA_PLUGIN_DIR));
				require_once(sprintf("%s/ajax/fea-loaders.php", BOOKEDFEA_PLUGIN_DIR));
				require_once(sprintf("%s/ajax/fea-actions.php", BOOKEDFEA_PLUGIN_DIR));
			
			}
				
			public function booked_fea_init(){
				
				if (is_user_logged_in() && current_user_can('edit_booked_appointments')):
				
					add_filter('booked_profile_tab_content', array(&$this, 'booked_fea_tabs'),1);
					add_filter('booked_profile_tabs',array(&$this, 'booked_fea_tabs'),1);
				
				endif;
				
			}
			
			public static function front_end_styles() {
				wp_enqueue_style('booked-fea-styles', BOOKEDFEA_PLUGIN_URL . '/css/styles.css', array(), BOOKEDFEA_VERSION);
			}
			
			public static function front_end_scripts() {
				wp_enqueue_script('booked-fea-js', BOOKEDFEA_PLUGIN_URL . '/js/functions.js', array(), BOOKEDFEA_VERSION, true);
			}
			
			public function inline_scripts() { ?>

				<script type="text/javascript">
	
					var i18n_confirm_appt_delete 	= '<?php echo esc_js(__('Are you sure you want to cancel this appointment?','booked-frontend-agents')); ?>',
						i18n_confirm_appt_approve	= '<?php echo esc_js(__('Are you sure you want to approve this appointment?','booked-frontend-agents')); ?>';
	
				</script>
	
			<?php }
			
			public function booked_fea_tabs($custom_tabs){
				
				$custom_tabs = array(
					'fea_appointments' => array(
						'title' => __('Upcoming Appointments','booked-frontend-agents'),
						'fa-icon' => 'fa-calendar',
						'class' => false
					),
					'fea_pending' => array(
						'title' => __('Pending Appointments','booked-frontend-agents') . '<div class="counter"></div>',
						'fa-icon' => 'fa-clock-o',
						'class' => false
					),
					'fea_history' => array(
						'title' => __('Appointment History','booked-frontend-agents'),
						'fa-icon' => 'fa-calendar-o',
						'class' => false
					),
					'edit' => array(
						'title' => __('Edit Profile','booked-frontend-agents'),
						'fa-icon' => 'fa-edit',
						'class' => 'edit-button'
					)
				);
				
				return $custom_tabs;
				
			}

		}
	}
	
	add_action('plugins_loaded','init_bookedfea');
	
} else {
	
	// Show notice when Booked is not active
	add_action('admin_notices', 'bookedfea_required_plugins_notice');

}

function init_bookedfea(){

	if(class_exists('bookedfea_plugin')) {
	
		// instantiate the plugin class
		$bookedfea_plugin = new bookedfea_plugin();
	
	}

}

function bookedfea_required_plugins_notice() {
			
	echo '<div class="update-nag">';
		echo sprintf( __('In order to use the %s plugin, you need to have %s installed and active.'), '<strong>Booked Front-End Agents</strong>', '<strong><a href="http://codecanyon.net/item/booked-appointment-booking-for-wordpress/9466968/?ref=boxystudio" target="_blank">Booked</a></strong>' );
	echo '</div>';
	
}

function booked_profile_content_fea_appointments(){
	echo '<div id="data-ajax-url">'.trailingslashit(home_url()).'</div>';
	echo do_shortcode('[booked-fea-appointments remove_wrapper=1]');	
}

function booked_profile_content_fea_history(){
	echo do_shortcode('[booked-fea-appointments remove_wrapper=1 historic=1]');	
}

function booked_profile_content_fea_pending(){
	echo do_shortcode('[booked-fea-appointments remove_wrapper=1 pending=1]');	
}

function booked_agent_appointments($user_id,$only_count = false,$time_format = false,$date_format = false,$calendar_ids = array(),$pending = false,$historic = false){

	if (!$date_format || !$time_format){
		$time_format = get_option('time_format');
		$date_format = get_option('date_format');
	}
	
	$order = $historic ? 'DESC' : 'ASC';

	$args = array(
		'post_type' => 'booked_appointments',
		'posts_per_page' => -1,
		'meta_key' => '_appointment_timestamp',
		'orderby' => 'meta_value_num',
		'order' => $order
	);
	
	if ($pending):
		$args['post_status'] = array('draft');
	else:
		$args['post_status'] = array('publish');
	endif;
	
	if ( class_exists('Booked_WC') && $pending ) {
		$args['post_status'][] = BOOKED_WC_PLUGIN_PREFIX . 'awaiting';
	}
	
	if (!empty($calendar_ids)):
		$args['tax_query'] = array(
			array(
				'taxonomy' => 'booked_custom_calendars',
				'field'    => 'term_id',
				'terms'    => $calendar_ids,
			)
		);
	else:
		$calendars = get_terms('booked_custom_calendars',array('order_by' => 'slug','hide_empty' => false));
		if (!empty($calendars)):
			if (current_user_can('manage_options')):
				
				foreach($calendars as $calendar):
					$calendar_ids[] = $calendar->term_id;
				endforeach;
			
				$args['tax_query'] = array(
					array(
						'taxonomy' => 'booked_custom_calendars',
						'field'    => 'term_id',
						'terms'    => $calendar_ids,
						'operator' => 'NOT IN'
					)
				);
				
			else:
				return array();
			endif;
		endif;
	endif;
	

	$appointments_array = array();

	$bookedAppointments = new WP_Query($args);

	if($bookedAppointments->have_posts()):
		while ($bookedAppointments->have_posts()):

			$bookedAppointments->the_post();
			global $post;
			$appt_date_value = date('Y-m-d',get_post_meta($post->ID, '_appointment_timestamp',true));
			$appt_timeslot = get_post_meta($post->ID, '_appointment_timeslot',true);
			$appt_timeslots = explode('-',$appt_timeslot);
			$appt_time_start = date('H:i:s',strtotime($appt_timeslots[0]));

			$appt_timestamp = strtotime($appt_date_value.' '.$appt_time_start);
			$current_timestamp = current_time('timestamp');

			$day = date('d',$appt_timestamp);
			$category = get_the_category();
			$calendar_id = wp_get_post_terms( $post->ID, 'booked_custom_calendars' );

			$guest_name = get_post_meta($post->ID, '_appointment_guest_name',true);
			$guest_email = get_post_meta($post->ID, '_appointment_guest_email',true);

			if (!$historic && $appt_timestamp >= $current_timestamp || $historic && $appt_timestamp < $current_timestamp){
				
				if (!$guest_name):
					$user_id = get_post_meta($post->ID, '_appointment_user',true);
					$appointments_array[$post->ID]['user'] = $user_id;
				else:
					$appointments_array[$post->ID]['guest_name'] = $guest_name;
					$appointments_array[$post->ID]['guest_email'] = $guest_email;
				endif;
				
				$appointments_array[$post->ID]['post_id'] = $post->ID;
				$appointments_array[$post->ID]['timestamp'] = $appt_timestamp;
				$appointments_array[$post->ID]['timeslot'] = $appt_timeslot;
				$appointments_array[$post->ID]['calendar_id'] = $calendar_id;
				$appointments_array[$post->ID]['status'] = $post->post_status;
			}

		endwhile;
		$appointments_array = apply_filters('booked_appointments_array', $appointments_array);
	endif;

	wp_reset_query();
	if ($only_count):
		return count($appointments_array);
	else :
		return $appointments_array;
	endif;

}

// Localization
function booked_fea_local_init(){
	$domain = 'booked-frontend-agents';
	$locale = apply_filters('plugin_locale', get_locale(), $domain);
	load_textdomain($domain, WP_LANG_DIR.'/plugins/'.$domain.'/'.$domain.'-'.$locale.'.mo');
	load_plugin_textdomain($domain, FALSE, dirname(plugin_basename(__FILE__)).'/languages/');
}
add_action('after_setup_theme', 'booked_fea_local_init');